Keen | Profile
Description: User profile overview

# Customer Relationship Management

New Order

### Profile

Reports
Brian Johnson
Lead Designer
44 8475 804342 brian@keenthemes.com @brianjohnson
Sales
USP: +23%
Reports
RNP: +30%

### Top Categories

Templates
Front-end, Admin
5.7k
+780
Wordpress
eCommerce, Website
2.8k
+350
eCommerce
Fashion Websites
9.3k
+2.1k
UI/UX Design
Everything you like
9.3k
+1.6k
SAAS Solution
Monthly Subscription
5.7k
+598

### General Statistics

XML CSV
Sales
USP:
+23%
Products
MRT:
+10%
Profit
FTP:
+19%
Reports
RNP:
+30%
Author Sales
Product Profit

### Work Progress

Pendings Tasks
78%
Completed Tasks
320 / 780
Tasks In Progress
45%
All Tasks
1200
Reports
40
Full Report
Pendings Tasks
78%
Completed Tasks
320 / 780
Tasks In Progress
45%
All Tasks
1200
Reports
40
Full Report

### Daily Salles

CSV
Chris Bent
SUV Themes Carp
$ 830
Ashley Stock
Merscedes Benz AMGww
$ 675
Jimmy Yesuku
All Nippon United Airlines
$ 194
Amanda West
Comboy Westem Limited
$ 65
Nick Holms
UILab Inc
$ 65

### Latest Tasks

Management meeting
09:30 AM
Replace datatables rows color
12:00 AM
Export Navitare booking table
01:20 PM
NYCS internal discussion
03: 00 PM
Project Launch
11: 00 AM
Server maintenance
4: 30 PM
Export Navitare booking table
01:20 PM
Replace datatables rows color
12:00 AM
Export Navitare booking table
01:20 PM
Replace datatables rows color
12:00 AM
NYCS internal discussion
03: 00 PM
Management meeting
09:30 AM
NYCS internal discussion
03: 00 PM
Replace datatables rows color
12:00 AM
Replace datatables rows color
12:00 AM
Export Navitare booking table
01:20 PM
Export Navitare booking table
01:20 PM
Management meeting
09:30 AM

### Quick Actions

Orders
Uploades
Products
Customers
Blog Posts
Settings
02:30 PM
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall
Yestardey
FlyMore design mock-ups been uploadet by designers Bob, Naomi, Richard
PSD, Sketch, AJ
Aug 13,2018
Meeting with Ken Digital Corp ot Unit14, 3 Edigor Buildings, George Street, Loondon
England, BA12FJ
Meeting, Customer
May 09, 2018
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall

### Recent Bills

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Orders

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Invoices

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### New Comments

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Recent Posts

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View
Notifications
Enable notifications:
Enable audit log:
Notify on new orders:
Orders
Enable order tracking:
Enable orders reports:
Allow order status auto update:
Customers
Enable customer singup:
Enable customers reporting:
Notifiy on new customer registration:

- Demos

### Select A Demo

Demo 1
Default RTL Version
Demo 2
Default RTL Version
Demo 3
Default RTL Version
Demo 4
Default RTL Version
Demo 5
Default RTL Version
Demo 6
Default RTL Version
Demo 7
Coming soon
Demo 8
Coming soon
Demo 9
Coming soon
Buy Keen Now!